cdsaxs.simulations package
==========================

Submodules
----------

cdsaxs.simulations.base module
------------------------------

.. automodule:: cdsaxs.simulations.base
   :members:
   :undoc-members:
   :show-inheritance:

cdsaxs.simulations.stacked\_trapezoid module
--------------------------------------------

.. automodule:: cdsaxs.simulations.stacked_trapezoid
   :members:
   :undoc-members:
   :show-inheritance:

cdsaxs.simulations.strong\_castle module
----------------------------------------

.. automodule:: cdsaxs.simulations.strong_castle
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cdsaxs.simulations
   :members:
   :undoc-members:
   :show-inheritance:
